base.BaseClient

Client mixin.

Usage

base.BaseClient()

Parameters

url: str

base url for requests

trailing: str = ""

trailing chars (e.g. /) appended to the url

**attrs
additional Session attributes

Methods

Name Description
__truediv__() Return a cloned client with appended path.
delete() DELETE request with optional path.
get() GET request with optional path.
head() HEAD request with optional path.
options() OPTIONS request with optional path.
patch() PATCH request with optional path and json body.
post() POST request with optional path and json body.
put() PUT request with optional path and json body.
request() Send request with relative or absolute path and return response.

__truediv__()

Return a cloned client with appended path.

Usage

__truediv__(path)

delete()

DELETE request with optional path.

Usage

delete(path="", **kwargs)

get()

GET request with optional path.

Usage

get(path="", **kwargs)


options()

OPTIONS request with optional path.

Usage

options(path="", **kwargs)

patch()

PATCH request with optional path and json body.

Usage

patch(path="", json=None, **kwargs)

post()

POST request with optional path and json body.

Usage

post(path="", json=None, **kwargs)

put()

PUT request with optional path and json body.

Usage

put(path="", json=None, **kwargs)

request()

Send request with relative or absolute path and return response.

Usage

request(method, path, **kwargs)